# Rcode for lecture 3

library(spatstat)
# if the spatstat package is not installed you can try using the install.packages() command

# make data into a point pattern object
X = matrix(runif(20),10,2) # 10 points as a matrix
W = owin(c(0,1),c(0,1)) # observation window
X = as.ppp(X,W=W) # object both containing points and window
par(mai=c(0.2,0.2,0.2,0.2)) # reduce margins (I have a small screen)
plot(X)
X
summary(X) # you can't see points directly in the point pattern object
cbind(X$x,X$y) # extracting points from point pattern
names(X) # other things can be extracted

# data sets in spatstat
data() # many datasets
data(cells) # point pattern representing center of cells
plot(cells)

# simulating a homogeneous Poisson process with intensity 100 on S=[0,1]x[0,1] 
lambda = 100 # intensity
W = owin(c(0,1),c(0,1))
X = rpoispp(lambda, win=W) # simulation
plot(X)

# simulating a marked (multitype) Poisson process
lambda = c(20,30,50) # intensity for each type
W = owin(c(0,1),c(0,1))
X = rmpoispp(lambda, win=W, types=c("A","B","C"))
plot(X)

# inhomogeneous Poisson process, intensity proportional to multivariate normal density
# (algorithm uses thinning of a homogeneous Poisson process)
lambda = function(x,y,a,b) {a*dnorm(x,0,b)*dnorm(y,0,b)} # intensity function
X = rpoispp(lambda, win=owin(c(-1,1),c(-1,1)),a=100,b=0.3) # simulation (using thinning)
plot(X)

# thinning a point process
X = rpoispp(300, win=owin(c(-1,1),c(-1,1)))
plot(X)
p = function(x,y) { ifelse(x^2+y^2 < 0.2, 1, 0.2) } # retention probability = prob. of keeping point
Y = rthin(X, p) # new point process - can you see what has happened?
plot(Y)

# superpositions of point processes
X = rpoispp(10, win=owin(c(-1,1),c(-1,1)))
Y = rpoispp(10, win=owin(c(-1,1),c(-1,1)))
Z = superimpose(X,Y) # superposition
par(mfrow=c(2,2))
plot(X)
plot(Y)
plot(Z)

# random displacements of point process
X = rpoispp(10, win=owin(c(-1,1),c(-1,1)))
Y = rjitter(X, radius=0.5, retry=TRUE, giveup = 10000)
# can only use uniform distribution on circle
par(mfrow=c(1,2))
plot(X)
plot(Y)
