# Rcode for lecture 7

library(spatstat)


### SIMULATED POINT PATTERN


# simulating a homogeneous Poisson process
par(mai=c(0.5,0.5,0.5,0.5))
X = rpoispp(100, win=owin(c(0,1),c(0,1)))
plot(X)

# intensity estimate
plot(density.ppp(X,sigma=0.1)) # Gaussian kernel smoothing, sigma = standard deviation
points(X) # for comparison

# intensity estimate - inhomogeneous inhomogeneous case
lambda = function(x,y,a,b) {a*dnorm(x,0,b)*dnorm(y,0,b)} # intensity function
Y = rpoispp(lambda, win=owin(c(-1,1),c(-1,1)),a=100,b=0.3) # simulation (using thinning)
plot(Y)
plot(density.ppp(Y,sigma=0.1)) 
points(Y)

# plotting L-function (homogeneous case again)
L = Lest(X)
plot(L) # green is the estimate from the slides
plot(L, .-r ~ r) # subtracting r to compare with 0-function

# plotting L-function with envelopes
e = envelope(X, Lest, nsim=39)
plot(e)
plot(e, .-r ~ r) # red = theoretical expression for Poisson, black = data

# other summary statistics
plot(Kest(X)) # green = estimate from slides 
plot(Fest(X)) # red = estimate from slides 
plot(Gest(X)) # red = estimate from slides   
plot(Jest(X)) # green = estimate from slides
plot(pcf(X)) # we didn't look at the estimate of this


### DATA


# let's look at some actual data - cells data
data(cells)
plot(cells) # looks rather homogeneous but regular - too regular for a Poisson process model?

e = envelope(cells, Lest, nsim=39)
plot(e, .-r ~ r) # clearly too regular at ranges 0.05-0.15

# This is an example of a preliminary data analysis,
# where we learn that the homogeneous Poisson process is a bad choice of model
# - a more complex model is needed!

# If we had fitted a model and used that for simulations instead of the Poisson process
# this would be a model checking procedure
