# R code for lecture 12

library(spatstat)
par(mai=c(0.5,0.5,0.5,0.5))

# defining MCMC run and output
nr = 10000 # no. of repetitions in MCMC run
nv = 0 # prints how far the algorithms has got every nv'th step
# 0 means "don't print"

# model specification and simulation - Strauss process
p1 = list(cif="strauss",par=list(beta=200,gamma=0.2,r=0.07),w=c(0,1,0,1))
X1 = rmh(model=p1,start=list(n.start=80),control=list(nrep=nr,nverb=nv))
plot(X1)

# Strauss process, conditioned on number of points (n=80)
p2 = list(cif="strauss",par=list(beta=200,gamma=0.2,r=0.07),w=c(0,1,0,1))
X2 = rmh(model=p2,start=list(n.start=80),control=list(p=1,nrep=nr,nverb=nv))
# p=1 means it only proposes move updates, no birth-death updates
plot(X2)

# inhomogeneous Strauss process
tr = function(x,y) {dnorm(x,0.5,0.1)*dnorm(y,0.5,0.1)}
p3 = list(cif="strauss",par=list(beta=200,gamma=0.2,r=0.07),w=c(0,1,0,1),trend=tr)
X3 = rmh(model=p3,start=list(n.start=80),control=list(nrep=nr,nverb=nv))
plot(X3)

# Pairwise interaction process (strictly speaking a multiscale process)
# interaction function
r = seq(from=0,to=0.2,length=101)[-1] # Drop 0.
h = 20*(r-0.05)
h[r<0.05] = 0
h[r>0.10] = 1
plot(r,h)
# simulation
p4 <- rmhmodel(cif="lookup",par=list(beta=10000,h=h,r=r),w=c(0,1,0,1))
X4 = rmh(model=p4,start=list(n.start=80),control=list(nrep=nr,nverb=nv))
plot(X4)

# Perfect simulation of the Strauss process
X5 <- rStrauss(0.05,0.2,1.5,square(141.4))
#beta=0.05, gamma=0.2, R=1.5, W=[0,141.4]^2, so dom. proc. has approx. 1000 points
plot(X5)
X6 <- rStrauss(100,0.7,0.05) #W=unit square
plot(X6)
